/**
 *  Copyright (c) 1997-2013, tinygroup.org (luo_guo@live.cn).
 *
 *  Licensed under the GPL, Version 3.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *       http://www.gnu.org/licenses/gpl.html
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 * --------------------------------------------------------------------------
 *  版权 (c) 1997-2013, tinygroup.org (luo_guo@live.cn).
 *
 *  本开源软件遵循 GPL 3.0 协议;
 *  如果您不遵循此协议，则不被允许使用此文件。
 *  你可以从下面的地址获取完整的协议文本
 *
 *       http://www.gnu.org/licenses/gpl.html
 */
package org.tinygroup.fileresolver;

import java.util.List;

import org.tinygroup.order.order.Order;
import org.tinygroup.vfs.FileObject;

/**
 * 文件查找器
 * 
 * @author luoguo
 * 
 */
public interface FileResolver extends Order {

	FileObject getClassesPath();

	/**
	 * 返回所有的文件处理器
	 * 
	 * @return
	 */
	List<FileProcessor> getFileProcessorList();

	/**
	 * 设置是否对classPath进行处理，默认为处理
	 * 
	 * @param classPathResolve
	 */
	void setClassPathResolve(boolean classPathResolve);

	/**
	 * 手动添加路径
	 * 
	 * @param path
	 */
	void addManualClassPath(String path);

	/**
	 * 手动添加跳过的匹配模式，如果模式匹配成功，则会被跳过
	 * 
	 * @param path
	 */
	void addSkipPathPattern(String pattern);

	List<String> getManualClassPaths();

	/**
	 * 增加文件处理器
	 * 
	 * @param fileProcessor
	 */
	void addFileProcessor(FileProcessor fileProcessor);

	/**
	 * 开始找文件
	 */
	void resolve();

	/**
	 * 
	 */
	void refresh();

	/**
	 * 获取是否扫描classsPath的状态位
	 * 
	 * @return
	 */
	boolean getClassPathResolve();

	/**
	 * 获取文件搜索器扫描的所有路径
	 * 
	 * @return
	 */
	List<String> getAllScanningPath();

	/**
	 * 获取文件处理的线程数目
	 * 
	 * @return
	 */
	int getFileProcessorThreadNum();

	/**
	 * 设置文件处理的线程数目
	 * 
	 * @param threadNum
	 */
	void setFileProcessorThreadNum(int threadNum);
}
